@@ -12,10 +12,10 @@ repo = configured.path_obj(git=True)
 log.debug(config)
 
 master = config.flow.master
-develop = config.flow.develop
+#develop = config.flow.develop
 
 ft = prefix_funcs(config.flow.feature)
-rl = prefix_funcs(config.flow.release)
+#rl = prefix_funcs(config.flow.release)
 
 @expose(docargs=True)
 def feature(ftargs):
